# Perceptron python package
A small perceptron package
## References - 

*[Official python docs for PYPI](https://packaging.python.org/en/latest/tutorials/packaging-projects/)

* [Github action file for PYPI](https://docs.github.com/en/actions/automating-builds-and-tests/building-and-testing-python#publishing-to-package-registries)